@@ -15,7 +15,7 @@ use CSS::Watcher::Parser;
 use CSS::Watcher::ParserLess;
 use CSS::Watcher::Monitor;
 
-our $VERSION = '0.3.6';
+our $VERSION = '0.4.0';
 
 use constant DEFAULT_HTML_STUFF_DIR => '~/.emacs.d/ac-html-csswatcher/completion/';
 
@@ -44,12 +44,17 @@ sub update {
         my $prj = $self->_get_project ($proj_dir);
         $prj->{parsed_files} = [];    # clean old parsed file list
 
+        my $changes = 0;
+
         my (@ignore, @allow);
         my $cfg = path($proj_dir)->child('.csswatcher');
 
         # clear project cache if .csswatcher changed
         if ($prj->{monitor}->is_changed($cfg)) {
+            INFO ('.csswatcher changed, resetting');
             $prj->{monitor}->make_dirty();
+            delete $prj->{parsed};
+            $changes++;
         }
 
         if (-f $cfg) {
@@ -64,7 +69,6 @@ sub update {
         }
 
         # scan new or changed files, cache them
-        my $changes = 0;
         $prj->{monitor}->scan (
             sub {
                 my $file = shift;
@@ -119,8 +123,15 @@ sub _parse_less {
     push @{$project->{parsed_files}}, $file;
 
     # normilize path of requiried files, they may have .././
-    $project->{imports_less}{$file} =
-        [ map {path($file)->parent->child($_)->realpath()->stringify} @{$requiries} ];
+    # eval {
+    #     $project->{imports_less}{$file} =
+    #         [ map {path($file)->parent->child($_)->realpath()->stringify} @{$requiries} ];
+    # };
+    # if ($@) {
+    #     WARN $@;
+    # }
+        $project->{imports_less}{$file} =
+            [ map {path($file)->parent->child($_)->realpath()->stringify} @{$requiries} ];
     return 1;
 }
 
@@ -175,6 +186,7 @@ sub project_stuff {
     return (\%classes, \%ids);
 }
 
+# clean old output html complete stuff and build new
 sub build_ac_html_stuff {
     my $self = shift;
     my $proj_dir = shift;
